<?php
if ( ! class_exists( 'RCP_Payment_Gateway' ) )
    return;
/**
 * Payment Gateway Mollie Class
 *
 * @package     Restrict Content Pro
 * @subpackage  Classes/Roles
 * @copyright   Copyright (c) 2012, Pippin Williamson
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       2.0
 */

/**
 * Register the gateway
 *
 * @since 2.1
 */

class RCP_Payment_Gateway_Mollie extends RCP_Payment_Gateway {

    /**
     * @var string
     */
    private $mollie_test_api;

    /**
     * @var string
     */
    private $mollie_live_api;

    /**
     * @var array
     */
    private $mollie_options;

    /**
     * @var Mollie_API_Client|string|null
     */
    private $mollie_client;

    /**
     * @var boolean
     */
    private $valid;

    /**
     * @var array
     */
    private $mollie_payment_methods;


    /**
     * Get things going
     *
     * @since 2.1
     */
    public function init() {

        global $rcp_options;

        $this->mollie_options = get_option( 'rcp_mollie_settings' );
        $this->mollie_test_api = $this->mollie_options['rcp_mollie_test_api_field'];
        $this->mollie_live_api = $this->mollie_options['rcp_mollie_live_api_field'];

        $this->supports[]  = 'one-time';
        $this->mollie_payment_methods = $this->mollie_options['mollie_gateways'];

        // Link RCP Mollie setting to RCP sandbox settings and update simultaniously
        if ($this->mollie_options['rcp_mollie_test_modus'] == 1) {
            $rcp_options['sandbox'] = 1;
        } else {
            $rcp_options['sandbox'] = 0;
        }
        $this->valid = isset($this->mollie_live_api) && isset($this->mollie_test_api) ? true : false;
        $this->test_mode = isset( $rcp_options['sandbox'] );
        if($this->valid) {
            $this->mollie_client = mollieApiConnect();
        }
    }

     /**
     * Process registration
     *
     * @since 2.1
     */
    public function process_signup() {
        if(!$this->valid) {
            return;
        }

        $webhookUrl = home_url() . '?listener=mollie';
        $payment = "";

        if( ! isset( $_POST['rcp_gateway'] ) ) {
            $gateway = 'ideal';
        } else {
            $gateway = sanitize_text_field( $_POST['rcp_gateway'] );
        }
        //var_dump($gateway);
        try {
            // Payment object for Mollie Payment Processing
            $payment = $this->mollie_client->payments->create(array(
                'amount' => $this->amount,
                'description' => $this->subscription_name,
                'redirectUrl' => $this->return_url,
                'webhookUrl' => $webhookUrl,
                'method' => $gateway,
                'metadata' => array(
                    'user_id'     	=> $this->user_id,
                    'item_number' 	=> $this->subscription_key,
                    'item_name'   	=> $this->subscription_name,
                    'discount_code' => $this->discount_code,
                    'payment_type' 	=> 'Mollie',
                    'date'          => date( 'Y-m-d g:i:s', time() )
                )
            ));
            //  write_log($payment);
        } catch (Mollie_API_Exception $e) {
            echo "API call failed: " . htmlspecialchars( $e->getMessage() );
        }

        $redirect_to_mollie = $payment->getPaymentUrl();

        wp_redirect( $redirect_to_mollie );
        exit;

    }

    /**
     * Process webhooks
     *
     * @since 2.1
     */
    public function process_webhooks() {
        if(!$this->valid) {
            return;
        }

        if( isset( $_POST['id'] ) && strpos($_POST['id'], 'tr_') === 0 ) {
            $mollie_id = $_POST["id"];
        } else {
            return;
        }
        $payment = $this->mollie_client->payments->get($mollie_id);
        $mollie_payment = new RCP_Mollie_Payments();

        // Check if Mollie payment ID exsists in the database
        // Prevents multiple payment inserts when Mollie sends
        // more then one payment notification
        if($mollie_payment->mollie_payment_exists(array('mollie_id' => $mollie_id))) {
            return;
        }

        // Get payment status
        $payment_status = $payment->status;
        $user = $payment->metadata->user_id;

        $payment_data = array(
            'date'              => date( 'Y-m-d g:i:s', time() ),
            'subscription'      => $payment->description,
            'payment_type' 		=> 'Mollie',
            'subscription_key' 	=> $payment->metadata->item_number,
            'amount' 			=> $payment->amount,
            'user_id' 			=> $payment->metadata->user_id,
            'transaction_id'   	=> $this->generate_transaction_id(),
            'mollie_id'			=> $mollie_id
        );

        switch( $payment_status ) :

            case "paid" :
                // record this payment in the database
                $mollie_payment->insert( $payment_data );
                $member = new RCP_Member( $user );
                $member->set_payment_profile_id( $mollie_id );

                if( ! $member || ! $member->get_subscription_id() ) {
                    die( 'no member found' );
                }
                $member->renew();

                rcp_email_subscription_status( $user, 'active' );
                if( ! isset( $rcp_options['disable_new_user_notices'] ) ) {
                    // send welcome email here
                    wp_new_user_notification( $user );
                }

                die( 'successful payment' );

                break;

            case "cancelled" :
                // write_log('Status is Cancelled');
                die( 'successful payment_profile_cancel' );

                break;

            case "expired" :
                // write_log('Status is Expired');
                die( 'successful payment_profile_expired' );

                break;

        endswitch;
    }
}