<?php
/**
 * Mollie RCP Helper functions
 * Author: Sander de Wijs
 * Date: 2-1-2016
 * Time: 16:12
 */

if(!class_exists('Mollie_API_Autoloader')) {
    require_once( 'Mollie/API/Autoloader.php' );
}

/**
 * Connect to Mollie via the API
 * @return Mollie_API_Client|null|string
 * @since 2.0
 */
function mollieApiConnect()
{
    $options = get_option('rcp_mollie_settings');

    if (NULL !== $options['rcp_mollie_test_api_field'] && NULL !== $options['rcp_mollie_live_api_field']) {
        $mollie = NULL;
        if ($options['rcp_mollie_test_modus'] !== 0 ) {
            $mollie_api = $options['rcp_mollie_test_api_field'];
        } else {
            $mollie_api = $options['rcp_mollie_live_api_field'];
        }

        try {
            $mollie = new Mollie_API_Client;
        } catch (Mollie_API_Exception $e) {
            echo "API call failed: " . htmlspecialchars($e->getMessage());
        }

        try {
            $mollie->setApiKey($mollie_api);
        } catch (Mollie_API_Exception $e) {
            echo "<p>" . "API call failed: " . htmlspecialchars($e->getMessage()) . "</p>";
        }
    } else {
        $mollie = 'No valid API keys set';
    }
    return $mollie;
}

/**
 * Validate if API keys are set
 * @return bool
 * @since 1.2
 */
function validate_mollie_gateway()
{
    $options = get_option('rcp_mollie_settings');
    $validation = false;
    if (isset($options['rcp_mollie_test_api_field']) && isset($options['rcp_mollie_live_api_field'])) {
        $validation = true;
    }
    return $validation;
}


/**
 * Validate Mollie API keys to prevent errors in settings page
 * @param string $mollie_api
 * @return string $api_check
 * @since 1.2
 */
function rcp_mollie_fields_validate($mollie_api)
{
    $mollie_api = htmlspecialchars($mollie_api);
    if (strpos($mollie_api, 'test_') === 0 || strpos($mollie_api, 'live_') === 0) {
        $api_check = 'valid';
    } else {
        $api_check = 'invalid';
    }
    return $api_check;
}

/**
 * Load active Mollie payment methods in RCP
 * @param array $gateways
 * @return array $gateways
 * @since 2.0
 */
function load_mollie_gateways($gateways) {

    $options = get_option( 'rcp_mollie_settings' );
    if(array_key_exists('mollie_gateways', $options) && isset($options['mollie_gateways'])) {
        $methods = $options['mollie_gateways'];

        foreach ($methods as $method) {
            $gateway = $method['id'];
            $label = $method['label'];
            $admin_label = $method['admin_label'];

            $gateways[$gateway] = array(
                'label' => $label,
                'admin_label' => $admin_label,
                'class' => 'RCP_Payment_Gateway_Mollie'
            );
        }
        return $gateways;
    }
    return $gateways;
}

add_filter('rcp_payment_gateways','load_mollie_gateways');
