<?php
if ( ! class_exists( 'RCP_Payments' ) )
    return;

/**
 *
 * Mollie payments class
 * Used to store the Mollie Payment ID in the database
 * and retrieve it to prevent duplicate payment updates.
 *
 */

class RCP_Mollie_Payments extends RCP_Payments {

    /**
     * Add a payment to the database
     *
     * @access  public
     * @param   $payment_data array All of the payment data, such as amount, date, user ID, etc
     * @since   1.5
     */

    public function insert( $payment_data = array() ) {

        global $wpdb;

        $defaults = array(
            'subscription'      => '',
            'date'              => date( 'Y-m-d H:i:s', current_time( 'timestamp' ) ),
            'amount'            => 0.00,
            'user_id'           => 0,
            'payment_type'      => '',
            'subscription_key'  => '',
            'transaction_id'    => '',
            'status'            => 'complete',
            'mollie_id'         => ''
        );

        $args = wp_parse_args( $payment_data, $defaults );

        if( $this->payment_exists( $args ) ) {
            return;
        }

        $wpdb->insert( $this->db_name, $args, array( '%s', '%s', '%s', '%d', '%s', '%s', '%s', '%s' ) );

        // if insert was succesful, return the payment ID
        if( $wpdb->insert_id ) {
            // clear the payment caches

            delete_transient( 'rcp_earnings' );
            delete_transient( 'rcp_payments_count' );

            // Remove trialing status, if it exists
            delete_user_meta( $args['user_id'], 'rcp_is_trialing' );

            do_action( 'rcp_insert_payment', $wpdb->insert_id, $args, $args['amount'] );

            return $wpdb->insert_id;

        }

        return false;

    }

    /**
     * Checks if a payment exists in the DB
     *
     * @access  public
     * @param   $args Array An array of the payment details we need to look for
     * @since   1.5
     */

    public function mollie_payment_exists( $args = array() ) {

        global $wpdb;

        $found = $wpdb->get_results(
            $wpdb->prepare(
                "SELECT id FROM " . $this->db_name . " WHERE `mollie|_id`='%s';",
                $args['mollie_id']
            )
        );

        if( $found )
            return true; // this payment already exists

        return false;

    }
}