<?php
/**
 * Functions for creating RCP Mollie settings
 * User: Sander de Wijs
 * Date: 4-1-2016
 * Time: 11:53
 */
require( 'helpers/mollie-rcp-helpers.php' );

function rcp_mollie_scripts_styles()
{
    $plugin_url = plugins_url();
    wp_register_style('rcp-mollie-styles', $plugin_url . '/rcp-mollie/assets/css/rcp-mollie-styles.css', '', '', '');
    wp_enqueue_script( 'rcp-mollie-form-script', $plugin_url . '/rcp-mollie/assets/js/jquery.form.js', array( 'jquery' ), '2013-07-18', true );
    wp_enqueue_style('rcp-mollie-styles');
}

/*
* Add a link to plugin settings in the admin menu
*/
if (!function_exists('rcp_mollie_settings_init')) {
    function rcp_mollie_settings_init()
    {
        register_setting('rcp-mollie-settings-group', 'rcp_mollie_settings');

        add_settings_section(
            'rcp_mollie_settings_section',
            'Mollie Gateway Settings',
            'rcp_mollie_section_callback',
            'mollie-rcp'
        );

        add_settings_field(
            'rcp_mollie_test_api_field',
            'Mollie test API key',
            'rcp_mollie_test_api_field_callback',
            'mollie-rcp',
            'rcp_mollie_settings_section'
        );
        add_settings_field(
            'rcp_mollie_live_api_field',
            'Mollie live API key',
            'rcp_mollie_live_api_field_callback',
            'mollie-rcp',
            'rcp_mollie_settings_section'
        );
        add_settings_field(
            'rcp_mollie_test_modus',
            'Mollie sandbox mode',
            'rcp_mollie_test_modus_field_callback',
            'mollie-rcp',
            'rcp_mollie_settings_section'
        );
        add_settings_field(
            'rcp_mollie_remove_settings',
            'Gegevens verwijderen',
            'rcp_mollie_remove_settings_field_callback',
            'mollie-rcp',
            'rcp_mollie_settings_section'
        );
    }
}

if (!function_exists('rcp_mollie_test_api_field_callback')) {
    function rcp_mollie_test_api_field_callback()
    {
        // Hier komt de daadwerkelijke html voor het tekstveld
        $options = get_option('rcp_mollie_settings');
        if (!isset($options['rcp_mollie_test_api_field'])) $options['rcp_mollie_test_api_field'] = '';

        echo '<input type="text" id="rcp_mollie_test_api_field" name="rcp_mollie_test_api_field" value="' . $options['rcp_mollie_test_api_field'] . '">';
    }
}

if (!function_exists('rcp_mollie_live_api_field_callback')) {
    function rcp_mollie_live_api_field_callback()
    {
        // Hier komt de daadwerkelijke html voor het tekstveld
        $options = get_option('rcp_mollie_settings');
        if (!isset($options['rcp_mollie_live_api_field'])) $options['rcp_mollie_live_api_field'] = '';

        echo '<input type="text" id="rcp_mollie_live_api_field" name="rcp_mollie_live_api_field" value="' . $options['rcp_mollie_live_api_field'] . '">';
    }
}

if (!function_exists('rcp_mollie_test_modus_field_callback')) {
    function rcp_mollie_test_modus_field_callback()
    {
        // Hier komt de daadwerkelijke html voor het tekstveld
        $options = get_option('rcp_mollie_settings');
        if (!isset($options['rcp_mollie_test_modus'])) $options['rcp_mollie_test_modus'] = 0;

        $html = '<input type="checkbox" id="rcp_mollie_test_modus" name="rcp_mollie_test_modus" value="1"' . checked(1, $options['rcp_mollie_test_modus'], false) . '>';
        $html .= '<label for="rcp_mollie_test_modus">Schakel testmodus in</label>';
        echo $html;
    }
}

if (!function_exists('rcp_mollie_remove_settings_field_callback')) {
    function rcp_mollie_remove_settings_field_callback()
    {
        // Hier komt de daadwerkelijke html voor het tekstveld
        $options = get_option('rcp_mollie_settings');
        if (!isset($options['rcp_mollie_remove_settings'])) $options['rcp_mollie_remove_settings'] = 0;

        $html = '<input type="checkbox" id="rcp_mollie_remove_settings" name="rcp_mollie_remove_settings" value="1"' . checked(1, $options['rcp_mollie_remove_settings'], false) . '>';
        $html .= '<label for="rcp_mollie_test_modus">Data verwijderen na deïnstallatie</label>';
        echo $html;
    }
}

if (!function_exists('rcp_mollie_section_callback')) {
    function rcp_mollie_section_callback()
    {
        // Hier komt de HTML voor de settings section
    }
}

function add_rcp_mollie_options_page()
{
    add_menu_page(
        'Restrict Content Pro Mollie Gateway',
        'Mollie RCP',
        'manage_options',
        'mollie-rcp',
        'rcp_mollie_options_page',
        'dashicons-cart'
    );
}

if (!function_exists('rcp_mollie_options_page')) {
    function rcp_mollie_options_page()
    {
        $options = get_option('rcp_mollie_settings');

        if (isset($options['rcp_mollie_test_modus'])) {
            $mollie_api = $options['rcp_mollie_test_api_field'];
        } else {
            $mollie_api = $options['rcp_mollie_live_api_field'];
        }

        ?>
        <div class="wrap">
            <div id="icon-options-general" class="icon32"></div>
            <h2>Mollie IDEAL for Restrict Content Pro</h2>
            <div id="rcp-mollie-updated" class="updated">
                <p>Wijzigingen succesvol opgeslagen!</p>
            </div>
            <div id="rcp-mollie-error" class="error">
                <p>Er is een fout opgetreden</p>
            </div>
            <p><strong>Let op</strong>, de optie 'Mollie sandbox mode' overschrijft de sandbox-mode optie in de
                instellingen van
                Restrict Content Pro. Gebruik daarom alleen de optie op deze pagina om te wisselen tussen live en
                test betalingen.</p>

            <p><strong>Activeer na het invullen van de Mollie API keys de betaalmethodes in de <a
                        href="/wp-admin/admin.php?page=rcp-settings#payments">Restrict Content Pro
                        instellingen</a></strong>
            </p>

            <form id="mollie_rcp_settings_form" method="post" action="">
                <?php
                    settings_fields('rcp-mollie-settings-group');
                    do_settings_sections('mollie-rcp');
                    submit_button();
                    wp_nonce_field( 'molliercpUpdateOptions_html', 'molliercpUpdateOptions_nonce' );
                ?>
                <input type="hidden" name="action" value="rcpMollieGatewayUpdate" />
                <hr>
                <?php
                    if ($options['rcp_mollie_test_modus'] == 1) {
                        $mollie_profile = 'test ';
                    } else {
                        $mollie_profile = 'live ';
                    }
                ?>
                <h3>Geactiveerde services</h3>

                <p>Dit zijn de services die geactiveerd zijn in je Mollie <?php echo $mollie_profile; ?>
                    websiteprofiel. Schakel meer betaalmethodes in via het <a
                        href="https://www.mollie.nl/beheer/betaalmethodes/" target="_blank">Mollie dashboard</a></p>
                <ul class="active-payment-methods">
                    <?php
                    $methods = "";
                    $options = get_option('rcp_mollie_settings');
                    if (rcp_mollie_fields_validate($options['rcp_mollie_test_api_field']) == 'valid' && rcp_mollie_fields_validate($options['rcp_mollie_live_api_field']) == 'valid') {

                        $methods = $options['mollie_gateways'];
                        if(array_key_exists('mollie_gateways', $options) && isset($options['mollie_gateways'])) {
                            foreach ($methods as $method) {
                                $html = '<li class="payment-method"><img src="' . $method['image'] . '">';
                                $html .= '<span class="description">' . $method['label'] . '</span></li>';
                                echo $html;
                            }
                        } else {
                            echo '<p>Er konden geen Gateways worden opgehaald bij Mollie. Check voor de zekerheid of er actieve betaalmethodes zijn in het Mollie Dashboard.</p>';
                        }

                    } else if (rcp_mollie_fields_validate($options['rcp_mollie_test_api_field']) == 'invalid' && rcp_mollie_fields_validate($options['rcp_mollie_live_api_field']) == 'invalid') {
                        echo '<p>Het lijkt erop dat je nog geen, of ongeldige, API keys hebt ingevuld. Deze zijn nodig om betalingen te verrichten met Mollie. Je vind je API keys in je betalingsprofiel in het <a href="https://www.mollie.nl/beheer/betaalmethodes/" target="_blank">Mollie dashboard</a>.</p>';
                    } else if (rcp_mollie_fields_validate($options['rcp_mollie_test_api_field']) == 'invalid') {
                        echo '<p>Het lijkt erop dat je nog geen, of een ongeldige, test API key hebt ingevuld. Je vind je API key in je betalingsprofiel in het <a href="https://www.mollie.nl/beheer/betaalmethodes/" target="_blank">Mollie dashboard</a>.</p>';
                    } else if (rcp_mollie_fields_validate($options['rcp_mollie_live_api_field']) == 'invalid') {
                        echo '<p>Het lijkt erop dat je nog geen, of een ongeldige, live API key hebt ingevuld.<br> Je vind je API key in je betalingsprofiel in het <a href="https://www.mollie.nl/beheer/betaalmethodes/" target="_blank">Mollie dashboard</a>.</p>';
                    } else {
                        return;
                    }
                    ?>
                </ul>
            </form>
            <script type="text/javascript">
                jQuery(document).on('submit', 'form', function(e){
                    e.preventDefault();
                    var formData = jQuery(this).serialize();
                       jQuery.post("<?php echo admin_url('admin-ajax.php', is_ssl() ? 'https' : 'http'); ?>", formData, function(response){
                           function delayedRefresh() {
                               timeoutID = window.setTimeout(location.reload(), 1000);
                           }
                           if(response == 0) {
                               jQuery("#rcp-mollie-error").fadeIn("slow");
                           }
                           if(response == 2) {
                               jQuery("#rcp-mollie-updated").fadeIn("slow");
                               delayedRefresh();
                           }
                        });
                });
            </script>
        </div>
        <?php
    }
}
